@@ -10,16 +10,14 @@ shinyServer(function(input, output, session) {
     # add plot_data code from make_data_vis.R
     # change any placeholder character values to input widgets
     
-    selected_color <- input$plot_color
+    .color <- input$plot_color
     
     plot_data <- data1 %>%
-      filter(color == selected_color) %>% 
+      filter(color == .color) %>% 
       mutate(cut = stringr::str_to_sentence(cut)) %>%
       group_by(cut, clarity, .drop = FALSE) %>%
-      summarise(average_price = round(mean(price), 0)) %>%
-      mutate(average_price_thousands = round(average_price / 1000, 1)) %>%
-      mutate(average_price = paste0("US$", prettyNum(average_price,  big.mark = ","))) %>% 
-      mutate_text(c("cut", "clarity", "average_price"))
+      summarise(price = mean(price)) %>%
+      mutate_text(c("cut", "clarity", "price")) 
     
     return(plot_data)
   }) %>% 
@@ -30,21 +28,22 @@ shinyServer(function(input, output, session) {
     # add plot code from make_data_vis.R
     # change any placeholder character values to input widgets
     # refer to a reactive plot_data object as plot_data()
-
-    selected_color <- input$plot_color
     
-    title <- paste0("Average diamond price of colour ", selected_color, " by cut and clarity")
+    .color <- input$plot_color
+    
+    title <- glue::glue("Average diamond price of colour {.color} by cut and clarity")
     x_title <- "Average price ($US thousands)"
     y_title <- "Cut"
     
-    plot <- gg_hbar_col(data = plot_data(), average_price_thousands, cut, clarity, 
-                            text_var = text,
-                            title = title, 
-                            x_title = x_title, 
-                            y_title = y_title,
-                            font_family = "Helvetica",
-                            mobile = input$isMobile)
-    
+    plot <- gg_hbar_col(plot_data(), price, cut, clarity, 
+                        text_var = text,
+                        title = title, 
+                        x_title = x_title, 
+                        y_title = y_title,
+                        x_labels = scales::comma_format(),
+                        col_labels = ggplot2::waiver(),
+                        font_family = "Helvetica", 
+                        mobile = input$isMobile)
     
     return(plot)
   }) %>% 
@@ -52,7 +51,7 @@ shinyServer(function(input, output, session) {
   
   output$plot_desktop <- plotly::renderPlotly({ 
     plotly::ggplotly(plot(), tooltip = "text") %>%
-      plotly_camera()
+      plotly_camera() 
   }) %>% 
     bindCache(input$plot_color)
   
@@ -87,18 +86,11 @@ shinyServer(function(input, output, session) {
     # change any placeholder character values to input widgets
     # refer to a reactive map_data object as map_data()
     # use reactive radius for points that get bigger as the user zooms in, if necessary 
-    
     # reactive_radius <-  case_when(input$map_zoom < 7, 1, ifelse(input$map_zoom < 9, 2, ifelse(input$map_zoom < 12, 3, 4)))  
 
-    pal <- c("#4575B4", "#D3D3D3", "#D73027")
-    names(pal) <- c("Improving", "Indeterminate", "Worsening")
-    
     title <- paste0("Monitored trends, 2008\u201317")
     
-    leaflet_sf_col(map_data(), 
-                   trend_category, 
-                   pal = pal, 
-                   col_method = "category",
+    leaflet_sf_col(map_data(), trend_category, 
                    title = title)
   }
   
@@ -113,13 +105,15 @@ shinyServer(function(input, output, session) {
   ### table ###
   
   table_data <- reactive({    # create a reactive table_data object
-    if(input$table_data == "Diamonds") ggplot2::diamonds %>% 
-      select(carat:price) %>% 
-      rlang::set_names(~snakecase::to_sentence_case(.))
-    
-    else if(input$table_data == "Storms") dplyr::storms %>% 
-      select(name, year, month, day, status, wind, pressure) %>% 
-      rlang::set_names(~snakecase::to_sentence_case(.))
+    if(input$table_data == "Diamonds") {
+      ggplot2::diamonds %>% 
+        select(carat:price) %>% 
+        rlang::set_names(~snakecase::to_sentence_case(.))
+    } else if(input$table_data == "Storms") {
+      dplyr::storms %>% 
+        select(name, year, month, day, status, wind, pressure) %>% 
+        rlang::set_names(~snakecase::to_sentence_case(.))
+    }
   })
   
   output$table <- DT::renderDT(
